# -*- coding: utf-8 -*-
# Copyright (c) 2019  Daniel Campos - Avanzosc S.L.
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl).

from osv import fields, osv
import decimal_precision as dp


class Product2BomWiz(osv.osv_memory):
    _name = 'product2bom.wiz'

    def default_get(self, cr, uid, fields, context=None):
        res = {}
        if context is None:
            context = {}
        if 'active_ids' in context:
            res.update({'bom_ids': context['active_ids']})
        return res

    _columns = {
        'bom_ids': fields.many2many(
            'mrp.bom', 'mrp_bom_product_rel', 'wiz_id', 'bom_id',
            'Bill of Materials'),
        'product_ids': fields.one2many('product2bom.wiz.line', 'wizard_id',
                                       'Components'),
    }

    def add_product2bom(self, cr, uid, ids, context=None):
        bom_obj = self.pool['mrp.bom']
        for wiz in self.browse(cr, uid, ids, context):
            for product_wiz_line in wiz.product_ids:
                for bom in wiz.bom_ids:
                    exist = False
                    for bom_line in bom.bom_lines:
                        if bom_line.product_id == product_wiz_line.product_id:
                            exist = True
                    if not exist:
                        bom_obj.create(
                            cr, uid,
                            {'product_id': product_wiz_line.product_id.id,
                             'product_qty': product_wiz_line.product_qty,
                             'product_uom': product_wiz_line.product_uom.id,
                             'date_start': product_wiz_line.date_start,
                             'date_stop': product_wiz_line.date_stop,
                             'name': product_wiz_line.product_id.name,
                             'type': 'normal',
                             'code': product_wiz_line.product_id.default_code,
                             'bom_id': bom.id
                             }, context)
        return {}


class Product2BomWizLine(osv.osv_memory):
    _name = 'product2bom.wiz.line'

    _columns = {
        'wizard_id': fields.many2one('product2bom.wiz', 'Wizard'),
        'product_id': fields.many2one('product.product', 'Product',
                                      required=True),
        'product_qty': fields.float(
            'Product Qty', required=True,
            digits_compute=dp.get_precision('Product UoM')),
        'product_uom': fields.many2one('product.uom', 'Product UOM',
                                       required=True),
        'date_start': fields.date('Valid From'),
        'date_stop': fields.date('Valid Until'),
    }

    def onchange_product_id(self, cr, uid, ids, product_id, context=None):
        """ Changes UoM and name if product_id changes.
        @param product_id: Changed product_id
        @return:  Dictionary of changed values
        """
        if product_id:
            prod = self.pool['product.product'].browse(cr, uid, product_id,
                                                       context=context)
            return {'value': {'product_uom': prod.uom_id.id}}
        return {}
